@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2013 pdfcrowd.com
+# Copyright (C) 2009-2014 pdfcrowd.com
 # 
 # Portions of this code:
 #   <http://code.activestate.com/recipes/146306/>
@@ -29,7 +29,7 @@ import httplib
 import mimetypes
 import socket
 
-__version__ = "2.4"
+__version__ = "2.5"
 
 
 # constants for Client.setPageLayout()
@@ -287,7 +287,7 @@ class Client:
         mime_type = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
         body.append('Content-Type: ' + mime_type)
         body.append('')
-        body.append(open(filename).read())
+        body.append(open(filename, 'rb').read())
         # finalize
         body.append('--' + boundary + '--')
         body.append('')
